
# Class: AuWidgetFinishButton

A widget representing a button that finishes product personalization and places an order.

For details, you can refer to the [FinishButton widget](https://customerscanvas.com/dev/editors/ui-framework/widgets/finish-button.html) topic.

```
{
  "widgets": [
    {
      "name": "agree-checkbox",
      "type": "checkbox",
      "params": {
        "prompt": "I approve the design.",
        "value": false
      }
    },
    {
      "name": "finish-btn",
      "type": "finish-button",
      "params": {
        "enabled": "{{$['agree-checkbox']._}}",
        "onClick": [
          "{{ #function cart.submit() }}"
        ]
      }
    }
  ]
}
```

## Hierarchy

* AuBaseInvisibleWidget

  ↳ **AuWidgetFinishButton**

## Implements

* [IWidget](../interfaces/iwidget.md)

## Index

### Properties

* [enabled](auwidgetfinishbutton.md#enabled)
* [params](auwidgetfinishbutton.md#params)
* [visible](auwidgetfinishbutton.md#visible)

### Accessors

* [template](auwidgetfinishbutton.md#static-template)

### Methods

* [checkInitDependenciesWidgets](auwidgetfinishbutton.md#checkinitdependencieswidgets)
* [resetPreloaderState](auwidgetfinishbutton.md#resetpreloaderstate)
* [showPreloader](auwidgetfinishbutton.md#showpreloader)
* [showToast](auwidgetfinishbutton.md#showtoast)

## Properties

###  enabled

• **enabled**: *boolean*

___

###  params

• **params**: *[IFinishButtonConfig](../interfaces/ifinishbuttonconfig.md)*

*Implementation of [IWidget](../interfaces/iwidget.md).[params](../interfaces/iwidget.md#optional-params)*

*Overrides [AuBaseWidget](aubasewidget.md).[params](aubasewidget.md#params)*

Button properties.

___

###  visible

• **visible**: *boolean*

## Accessors

### `Static` template

• **get template**(): *HTMLTemplateElement*

*Inherited from void*

**Returns:** *HTMLTemplateElement*

## Methods

###  checkInitDependenciesWidgets

▸ **checkInitDependenciesWidgets**(): *string[]*

*Inherited from [AuBaseWidget](aubasewidget.md).[checkInitDependenciesWidgets](aubasewidget.md#checkinitdependencieswidgets)*

Returns an array of widget names, due to which the current widget cannot receive parameters.

**Returns:** *string[]*

___

###  resetPreloaderState

▸ **resetPreloaderState**(): *void*

*Inherited from [AuBaseWidget](aubasewidget.md).[resetPreloaderState](aubasewidget.md#resetpreloaderstate)*

**Returns:** *void*

___

###  showPreloader

▸ **showPreloader**(`isPreload`: boolean, `message`: string | string[], `timeout`: number): *void*

*Inherited from [AuBaseWidget](aubasewidget.md).[showPreloader](aubasewidget.md#showpreloader)*

Shows a preloader.

```
"onClick": [
  "{{#function main.showPreloader(true, 'Creating print files...')}}",
  "{{#function $['editor'].getHiResImages(800,800)}}",
  "{{#function main.showPreloader(false)}}"
]
```

**Parameters:**

Name | Type | Default | Description |
------ | ------ | ------ | ------ |
`isPreload` | boolean | - | If `true`, enables the preloader. |
`message` | string &#124; string[] |  [""] | A text message that appears next to the preloader.  |
`timeout` | number | 5 | - |

**Returns:** *void*

___

###  showToast

▸ **showToast**(`data?`: string, `duration?`: number): *void*

*Inherited from [AuBaseWidget](aubasewidget.md).[showToast](aubasewidget.md#showtoast)*

Shows a toast.

```
return editor.loadUserInfo(data)
    .catch(err => {
        this.widget.showToast("Error: Invalid data");
        console.log(err);
    });
```

**Parameters:**

Name | Type | Description |
------ | ------ | ------ |
`data?` | string | A string message to display in the toast. |
`duration?` | number | Defines how long to show the toast for.  |

**Returns:** *void*
