
# Class: AuWidgetInputText

A widget representing a text input field.

For details, you can refer to the [InputText widget](https://customerscanvas.com/dev/editors/ui-framework/widgets/input-text.html) topic.
```
{
  "widgets": [
    {
      {
        "name": "quantity-selector",
        "type": "input-text",
        "title": "How many cards?",
        "params": {
          "prompt": "Select quantity",
          "defaultValue": "{{ Math.max(order.quantity, 25) }}",
          "type": "number",
          "min": 25
        }
      }
    }
  ]
}
```

## Hierarchy

  ↳ [AuBaseSelectorWidget](aubaseselectorwidget.md)

  ↳ **AuWidgetInputText**

## Implements

* [IWidget](../interfaces/iwidget.md)
* [IRestorableWidget](../interfaces/irestorablewidget.md)

## Index

### Properties

* [defaultValue](auwidgetinputtext.md#defaultvalue)
* [params](auwidgetinputtext.md#params)
* [value](auwidgetinputtext.md#value)

### Accessors

* [_](auwidgetinputtext.md#_)
* [invalid](auwidgetinputtext.md#invalid)

### Methods

* [checkInitDependenciesWidgets](auwidgetinputtext.md#checkinitdependencieswidgets)
* [clearSelection](auwidgetinputtext.md#clearselection)
* [exportWidgetData](auwidgetinputtext.md#exportwidgetdata)
* [resetPreloaderState](auwidgetinputtext.md#resetpreloaderstate)
* [restoreWidgetFromData](auwidgetinputtext.md#restorewidgetfromdata)
* [showPreloader](auwidgetinputtext.md#showpreloader)
* [showToast](auwidgetinputtext.md#showtoast)

## Properties

###  defaultValue

• **defaultValue**: *string | number*

The default value.

___

###  params

• **params**: *[IInputTextConfig](../interfaces/iinputtextconfig.md)*

*Implementation of [IWidget](../interfaces/iwidget.md).[params](../interfaces/iwidget.md#optional-params)*

*Overrides [AuBaseWidget](aubasewidget.md).[params](aubasewidget.md#params)*

Properties of the widget.

___

###  value

• **value**: *string | number*

The current value.

## Accessors

###  _

• **get _**(): *string | number*

*Overrides [AuBaseSelectorWidget](aubaseselectorwidget.md).[_](aubaseselectorwidget.md#_)*

**Returns:** *string | number*

___

###  invalid

• **get invalid**(): *any*

**Returns:** *any*

## Methods

###  checkInitDependenciesWidgets

▸ **checkInitDependenciesWidgets**(): *string[]*

*Inherited from [AuBaseWidget](aubasewidget.md).[checkInitDependenciesWidgets](aubasewidget.md#checkinitdependencieswidgets)*

Returns an array of widget names, due to which the current widget cannot receive parameters.

**Returns:** *string[]*

___

###  clearSelection

▸ **clearSelection**(): *void*

*Overrides [AuBaseSelectorWidget](aubaseselectorwidget.md).[clearSelection](aubaseselectorwidget.md#abstract-clearselection)*

**Returns:** *void*

___

###  exportWidgetData

▸ **exportWidgetData**(`force`: boolean): *Promise‹InputTextData›*

*Implementation of [IRestorableWidget](../interfaces/irestorablewidget.md)*

**Parameters:**

Name | Type |
------ | ------ |
`force` | boolean |

**Returns:** *Promise‹InputTextData›*

___

###  resetPreloaderState

▸ **resetPreloaderState**(): *void*

*Inherited from [AuBaseWidget](aubasewidget.md).[resetPreloaderState](aubasewidget.md#resetpreloaderstate)*

**Returns:** *void*

___

###  restoreWidgetFromData

▸ **restoreWidgetFromData**(`widgetData`: InputTextData, `force`: boolean): *Promise‹void›*

**Parameters:**

Name | Type |
------ | ------ |
`widgetData` | InputTextData |
`force` | boolean |

**Returns:** *Promise‹void›*

___

###  showPreloader

▸ **showPreloader**(`isPreload`: boolean, `message`: string | string[], `timeout`: number): *void*

*Inherited from [AuBaseWidget](aubasewidget.md).[showPreloader](aubasewidget.md#showpreloader)*

Shows a preloader.

```
"onClick": [
  "{{#function main.showPreloader(true, 'Creating print files...')}}",
  "{{#function $['editor'].getHiResImages(800,800)}}",
  "{{#function main.showPreloader(false)}}"
]
```

**Parameters:**

Name | Type | Default | Description |
------ | ------ | ------ | ------ |
`isPreload` | boolean | - | If `true`, enables the preloader. |
`message` | string &#124; string[] |  [""] | A text message that appears next to the preloader.  |
`timeout` | number | 5 | - |

**Returns:** *void*

___

###  showToast

▸ **showToast**(`data?`: string, `duration?`: number): *void*

*Inherited from [AuBaseWidget](aubasewidget.md).[showToast](aubasewidget.md#showtoast)*

Shows a toast.

```
return editor.loadUserInfo(data)
    .catch(err => {
        this.widget.showToast("Error: Invalid data");
        console.log(err);
    });
```

**Parameters:**

Name | Type | Description |
------ | ------ | ------ |
`data?` | string | A string message to display in the toast. |
`duration?` | number | Defines how long to show the toast for.  |

**Returns:** *void*
