
# Class: AuWidgetSlider

A widget that is used to display multiple images together.

The following example illustrates how you can initialize a slider with proof images obtained from the Design Editor.
```
{
  "widgets": [{
    "name": "preview",
    "type": "slider",
    "params": {
      "style": {
        "--au-widget-background": "#ffffff",
        "--au-widget-height": "480px"
      },
      "direction": "tile",
      "rows": 1,
      "columns": 2,
      "showImageIndex": false,
      "lightbox": false,
      "images": {
        "{{ #each $['editor'].proofImageUrls as url }}": {
          "url": "{{ url[0] }}"
        }
      }
    }
  }]
}
```

## Hierarchy

  ↳ [AuBaseWidget](aubasewidget.md)

  ↳ **AuWidgetSlider**

## Implements

* [IWidget](../interfaces/iwidget.md)

## Index

### Properties

* [params](auwidgetslider.md#params)

### Methods

* [backImage](auwidgetslider.md#backimage)
* [checkInitDependenciesWidgets](auwidgetslider.md#checkinitdependencieswidgets)
* [nextImage](auwidgetslider.md#nextimage)
* [resetPreloaderState](auwidgetslider.md#resetpreloaderstate)
* [showPreloader](auwidgetslider.md#showpreloader)
* [showToast](auwidgetslider.md#showtoast)

## Properties

###  params

• **params**: *any*

*Implementation of [IWidget](../interfaces/iwidget.md).[params](../interfaces/iwidget.md#optional-params)*

*Inherited from [AuBaseWidget](aubasewidget.md).[params](aubasewidget.md#params)*

Compiled widget configuration.

## Methods

###  backImage

▸ **backImage**(): *void*

Navigates to the previous image.

**Returns:** *void*

___

###  checkInitDependenciesWidgets

▸ **checkInitDependenciesWidgets**(): *string[]*

*Inherited from [AuBaseWidget](aubasewidget.md).[checkInitDependenciesWidgets](aubasewidget.md#checkinitdependencieswidgets)*

Returns an array of widget names, due to which the current widget cannot receive parameters.

**Returns:** *string[]*

___

###  nextImage

▸ **nextImage**(): *void*

Navigates to the next image.

**Returns:** *void*

___

###  resetPreloaderState

▸ **resetPreloaderState**(): *void*

*Inherited from [AuBaseWidget](aubasewidget.md).[resetPreloaderState](aubasewidget.md#resetpreloaderstate)*

**Returns:** *void*

___

###  showPreloader

▸ **showPreloader**(`isPreload`: boolean, `message`: string | string[], `timeout`: number): *void*

*Inherited from [AuBaseWidget](aubasewidget.md).[showPreloader](aubasewidget.md#showpreloader)*

Shows a preloader.

```
"onClick": [
  "{{#function main.showPreloader(true, 'Creating print files...')}}",
  "{{#function $['editor'].getHiResImages(800,800)}}",
  "{{#function main.showPreloader(false)}}"
]
```

**Parameters:**

Name | Type | Default | Description |
------ | ------ | ------ | ------ |
`isPreload` | boolean | - | If `true`, enables the preloader. |
`message` | string &#124; string[] |  [""] | A text message that appears next to the preloader.  |
`timeout` | number | 5 | - |

**Returns:** *void*

___

###  showToast

▸ **showToast**(`data?`: string, `duration?`: number): *void*

*Inherited from [AuBaseWidget](aubasewidget.md).[showToast](aubasewidget.md#showtoast)*

Shows a toast.

```
return editor.loadUserInfo(data)
    .catch(err => {
        this.widget.showToast("Error: Invalid data");
        console.log(err);
    });
```

**Parameters:**

Name | Type | Description |
------ | ------ | ------ |
`data?` | string | A string message to display in the toast. |
`duration?` | number | Defines how long to show the toast for.  |

**Returns:** *void*
