
# Interface: I3DViewerNewParams

Provides properties that are used to visualize 3D models.

For more details, you can refer to the [[AuWidget3DViewer|3D-Viewer widget].

The following example illustrates how you can specify a two-sided model in the `3D-Viewer` widget.
```
{
    "widgets": [{
        "name": "preview",
        "type": "3d-viewer",
        "params": {
            "showAnimationButtons": false,
            "showCameraButtons": false,
            "items": [{
                "images": [
                    "https://example.com/800/600",
                    "https://example.com/1000/601"
                ],
                "model": "64057c8e12287dfc3d0ecebc"
            }]
        }
    }]
}
```

## Hierarchy

* **I3DViewerNewParams**

## Index

### Properties

* [animationSpeed](i3dviewernewparams.md#animationspeed)
* [backgroundColor](i3dviewernewparams.md#backgroundcolor)
* [buttonsPosition](i3dviewernewparams.md#optional-buttonsposition)
* [cameraButtons](i3dviewernewparams.md#optional-camerabuttons)
* [distance](i3dviewernewparams.md#optional-distance)
* [items](i3dviewernewparams.md#items)
* [modelType](i3dviewernewparams.md#modeltype)
* [orbitsControl](i3dviewernewparams.md#optional-orbitscontrol)
* [pauseAtEnd](i3dviewernewparams.md#pauseatend)
* [preloader](i3dviewernewparams.md#optional-preloader)
* [saveDistanceWhenMoveCamera](i3dviewernewparams.md#savedistancewhenmovecamera)
* [showAnimationButtons](i3dviewernewparams.md#optional-showanimationbuttons)
* [showAnimationControls](i3dviewernewparams.md#optional-showanimationcontrols)
* [showCameraButtons](i3dviewernewparams.md#optional-showcamerabuttons)

## Properties

###  animationSpeed

• **animationSpeed**: *number*

Speed of animation playing

___

###  backgroundColor

• **backgroundColor**: *string*

Background color for scene.

___

### `Optional` buttonsPosition

• **buttonsPosition**? : *ButtonsPosition*

The position of the camera and animation button: `left`, `right`, or `top`. By default: `left`.

___

### `Optional` cameraButtons

• **cameraButtons**? : *Partial‹object›*

___

### `Optional` distance

• **distance**? : *number*

Distance from camera to scene

___

###  items

• **items**: *I3DItem[]*

A collection of objects for visualization.

___

###  modelType

• **modelType**: *[ModelType](../enums/modeltype.md)*

The model type: `default` or `blender`.

___

### `Optional` orbitsControl

• **orbitsControl**? : *any*

Parameters for OrbitControls. https://threejs.org/docs/#examples/en/controls/OrbitControls

___

###  pauseAtEnd

• **pauseAtEnd**: *boolean*

If `true`, pauses animation at the last frame.

___

### `Optional` preloader

• **preloader**? : *boolean*

Show/hide origami preloader

___

###  saveDistanceWhenMoveCamera

• **saveDistanceWhenMoveCamera**: *boolean*

If `true`, saves camera distance position when select another camera button view.

___

### `Optional` showAnimationButtons

• **showAnimationButtons**? : *boolean*

If a model has several elements (for example, if a box consists of a container and a lid), you can set this parameter to `true` to enable buttons for opening and closing these elements.

___

### `Optional` showAnimationControls

• **showAnimationControls**? : *boolean*

if `true`, shows Play\Pause button, animation timeline and animation speed controls.

___

### `Optional` showCameraButtons

• **showCameraButtons**? : *boolean*

If `true`, enables camera buttons. If it's a string array - show buttons with that name.
